@@ -24,6 +24,8 @@ include("scripts/File/Print/Print.js");
 function PageSettings() {
 }
 
+PageSettings.prototype = new Object();
+
 PageSettings.getPreferencesCategory = function(appPreferences) {
     if (appPreferences) {
         return [ qsTr("Defaults for New Drawings"), qsTr("Printing - Page") ];
@@ -35,106 +37,111 @@ PageSettings.getPreferencesCategory = function(appPreferences) {
  * Available paper sizes. Some are defined by Qt, the rest are custom
  * paper sizes.
  */
-PageSettings.paperSizes = new Array(
-        [ qsTr("Custom"), new QSizeF(), QPrinter.Custom ],
-        
-        [ "ISO A0",  new QSizeF(841, 1189), QPrinter.A0 ],
-        [ "ISO A1",  new QSizeF(594,  841), QPrinter.A1 ],
-        [ "ISO A2",  new QSizeF(420,  594), QPrinter.A2 ],
-        [ "ISO A3",  new QSizeF(297,  420), QPrinter.A3 ],
-        [ "ISO A4",  new QSizeF(210,  297), QPrinter.A4 ],
-        [ "ISO A5",  new QSizeF(148,  210), QPrinter.A5 ],
-        [ "ISO A6",  new QSizeF(105,  148), QPrinter.A6 ],
-        [ "ISO A7",  new QSizeF( 74,  105), QPrinter.A7 ],
-        [ "ISO A8",  new QSizeF( 52,   74), QPrinter.A8 ],
-        [ "ISO A9",  new QSizeF( 37,   52), QPrinter.A9 ],
-        [ "ISO A10", new QSizeF( 26,   37), QPrinter.Custom ],
-        
-        [ "ISO B0",  new QSizeF(1000, 1414), QPrinter.B0 ],
-        [ "ISO B1",  new QSizeF( 707, 1000), QPrinter.B1 ],
-        [ "ISO B2",  new QSizeF( 500,  707), QPrinter.B2 ],
-        [ "ISO B3",  new QSizeF( 353,  500), QPrinter.B3 ],
-        [ "ISO B4",  new QSizeF( 250,  353), QPrinter.B4 ],
-        [ "ISO B5",  new QSizeF( 176,  250), QPrinter.B5 ],
-        [ "ISO B6",  new QSizeF( 125,  176), QPrinter.B6 ],
-        [ "ISO B7",  new QSizeF(  88,  125), QPrinter.B7 ],
-        [ "ISO B8",  new QSizeF(  62,   88), QPrinter.B8 ],
-        [ "ISO B9",  new QSizeF(  44,   62), QPrinter.B9 ],
-        [ "ISO B10", new QSizeF(  31,   44), QPrinter.B10 ],
-          
-        [ "ISO C0",  new QSizeF( 917, 1297), QPrinter.Custom ],
-        [ "ISO C1",  new QSizeF( 648,  917), QPrinter.Custom ],
-        [ "ISO C2",  new QSizeF( 458,  648), QPrinter.Custom ],
-        [ "ISO C3",  new QSizeF( 324,  458), QPrinter.Custom ],
-        [ "ISO C4",  new QSizeF( 229,  324), QPrinter.Custom ],
-        [ "ISO C5",  new QSizeF( 162,  229), QPrinter.Custom ],
-        [ "ISO C6",  new QSizeF( 114,  162), QPrinter.Custom ],
-        [ "ISO C7",  new QSizeF(  81,  114), QPrinter.Custom ],
-        [ "ISO C8",  new QSizeF(  57,   81), QPrinter.Custom ],
-        [ "ISO C9",  new QSizeF(  40,   57), QPrinter.Custom ],
-        [ "ISO C10", new QSizeF(  28,   40), QPrinter.Custom ],
+var pageNames = [ 
+    qsTr("Custom"), 
+    "ISO A0",
+    "ISO A1",
+    "ISO A2",
+    "ISO A3",
+    "ISO A4",
+    "ISO A5",
+    "ISO A6",
+    "ISO A7",
+    "ISO A8",
+    "ISO A9",
+    "ISO A10",
+    
+    "ISO B0",
+    "ISO B1",
+    "ISO B2",
+    "ISO B3",
+    "ISO B4",
+    "ISO B5",
+    "ISO B6",
+    "ISO B7",
+    "ISO B8",
+    "ISO B9",
+    "ISO B10",
+      
+    "ISO C0",
+    "ISO C1",
+    "ISO C2",
+    "ISO C3",
+    "ISO C4",
+    "ISO C5",
+    "ISO C6",
+    "ISO C7",
+    "ISO C8",
+    "ISO C9",
+    "ISO C10",
 
-        [ "DIN 476 4A0", new QSizeF(1682, 2378), QPrinter.Custom ],
-        [ "DIN 476 2A0", new QSizeF(1189, 1682), QPrinter.Custom ],
+    "DIN 476 4A0",
+    "DIN 476 2A0",
 
-        // JIS:
-        [ "JIS B0",  new QSizeF(1030, 1456), QPrinter.Custom ],
-        [ "JIS B1",  new QSizeF( 728, 1030), QPrinter.Custom ],
-        [ "JIS B2",  new QSizeF( 515,  728), QPrinter.Custom ],
-        [ "JIS B3",  new QSizeF( 364,  515), QPrinter.Custom ],
-        [ "JIS B4",  new QSizeF( 257,  364), QPrinter.Custom ],
-        [ "JIS B5",  new QSizeF( 182,  257), QPrinter.Custom ],
-        [ "JIS B6",  new QSizeF( 128,  182), QPrinter.Custom ],
-        [ "JIS B7",  new QSizeF(  91,  128), QPrinter.Custom ],
-        [ "JIS B8",  new QSizeF(  64,   91), QPrinter.Custom ],
-        [ "JIS B9",  new QSizeF(  45,   64), QPrinter.Custom ],
-        [ "JIS B10", new QSizeF(  32,   45), QPrinter.Custom ],
-        [ "JIS B11", new QSizeF(  22,   32), QPrinter.Custom ],
-        [ "JIS B12", new QSizeF(  16,   22), QPrinter.Custom ],
+    // JIS:
+    "JIS B0",
+    "JIS B1",
+    "JIS B2",
+    "JIS B3",
+    "JIS B4",
+    "JIS B5",
+    "JIS B6",
+    "JIS B7",
+    "JIS B8",
+    "JIS B9",
+    "JIS B10",
+    "JIS B11",
+    "JIS B12",
 
-        // 7.5" x 10"
-        [ "Executive",  new QSizeF(190.5, 254), QPrinter.Executive ],
-        // 8.5" x 14"
-        [ "Legal",      new QSizeF(215.9, 355.6), QPrinter.Legal ],
-        // 8.5" x 11"
-        [ "ANSI A (Letter)", new QSizeF(215.9, 279.4), QPrinter.Letter ],
-        // 11" x 17"
-        [ "ANSI B (Ledger, Tabloid)", new QSizeF(279.4, 431.8), QPrinter.Tabloid ],
-        // 13" x 19"
-        [ "Super B",    new QSizeF(330.2, 482.6), QPrinter.Custom ],
-        // 17" x 22"
-        [ "ANSI C",     new QSizeF(431.8, 558.8), QPrinter.Custom ],
-        // 22" x 34"
-        [ "ANSI D",     new QSizeF(558.8, 863.6), QPrinter.Custom ],
-        // 34" x 44"
-        [ "ANSI E",     new QSizeF(863.6, 1117.6), QPrinter.Custom ],
+    // 7.5" x 10"
+    "Executive",
+    // 8.5" x 14"
+    "Legal",
+    // 8.5" x 11"
+    "ANSI A (Letter)",
+    // 11" x 17"
+    "ANSI B (Ledger, Tabloid)",
+    // 13" x 19"
+    "Super B",
+    // 17" x 22"
+    "ANSI C",
+    // 22" x 34"
+    "ANSI D",
+    // 34" x 44"
+    "ANSI E",
 
-        // US Architectural:
-        // 9" x 12"
-        [ "Arch A",     new QSizeF(228.6, 304.8), QPrinter.Custom ],
-        // 12" x 18"
-        [ "Arch B",     new QSizeF(304.8, 457.2), QPrinter.Custom ],
-        // 18" x 24"
-        [ "Arch C",     new QSizeF(457.2, 609.6), QPrinter.Custom ],
-        // 24" x 36"
-        [ "Arch D",     new QSizeF(609.6, 914.4), QPrinter.Custom ],
-        // 36" x 48"
-        [ "Arch E",     new QSizeF(914.4, 1219.2), QPrinter.Custom ],
-        // 30" x 42"
-        [ "Arch E1",    new QSizeF(762, 1066.8), QPrinter.Custom ],
-        // 26" x 38"
-        [ "Arch E2",    new QSizeF(660.4, 965.2), QPrinter.Custom ],
-        // 27" x 39"
-        [ "Arch E3",    new QSizeF(685.8, 990.6), QPrinter.Custom ],
+    // US Architectural:
+    // 9" x 12"
+    "Arch A",
+    // 12" x 18"
+    "Arch B",
+    // 18" x 24"
+    "Arch C",
+    // 24" x 36"
+    "Arch D",
+    // 36" x 48"
+    "Arch E",
+    // 30" x 42"
+    "Arch E1",
+    // 26" x 38"
+    "Arch E2",
+    // 27" x 39"
+    "Arch E3",
 
-        // Others:
-        // Folio / Foolscap:
-        [ "F4 (Folio, Foolscap)", new QSizeF( 210,   330), QPrinter.Folio ],
-        // U.S. Common 10 Envelope:
-        [ "Common 10 Envelope", new QSizeF(105, 241), QPrinter.Comm10E ],
-        // DLE Envelope:
-        [ "DLE Envelope", new QSizeF( 110,   220), QPrinter.DLE ]
-);
+    // Others:
+    // Folio / Foolscap:
+    "F4 (Folio, Foolscap)",
+    // U.S. Common 10 Envelope:
+    "Common 10 Envelope",
+    // DLE Envelope:
+    "DLE Envelope"
+];
+
+PageSettings.paperSizes = new Array();
+
+for (var i=0; i<pageNames.length; i++) {
+    PageSettings.paperSizes.push([pageNames[i], RS.getPageSize(pageNames[i]), RS.getPageSizeId(pageNames[i])]);
+}
 
 /**
  * Called when the user changed the drawing / global paper unit in another
@@ -159,7 +166,6 @@ PageSettings.updatePaperUnit = function(unit) {
     //PageSettings.widgets["PaperWidth"].setValue();
 };
 
-
 PageSettings.getPreferencesScope = function() {
     return "block";
 };
@@ -229,7 +235,7 @@ PageSettings.postInitPreferences = function(pageWidget, calledByPrefDialog, docu
         widgets["PaperSizeName"].currentIndex = idx;
     }
 
-    paperSizeNameCombo["currentIndexChanged(int)"].connect(PageSettings, "updatePaperSize");
+    paperSizeNameCombo["currentIndexChanged(int)"].connect(PageSettings, PageSettings.updatePaperSize);
 
     PageSettings.updatePaperSize(widgets["PaperSizeName"].currentIndex);
 
