@@ -135,7 +135,7 @@ Explode.explodeSelection = function(di, toolTitle) {
                     e = shapeToEntity(entity.getDocument(), newShape);
                     if (!isNull(e)) {
                         e.setSelected(true);
-                        e.copyAttributesFrom(entity.data());
+                        e.copyAttributesFrom(getPtr(entity));
                         if (!isNull(newShape.color)) {
                             e.setColor(new RColor(newShape.color));
                         }
@@ -278,7 +278,18 @@ Explode.explodeEntity = function(entity, options) {
         if (RPolyline.hasProxy() && polyline.hasWidths()) {
 
             // list of polyline pairs (left / right):
-            var pls = polyline.getLeftRightOutline();
+            var pls;
+            if (RSettings.getQtVersion() >= 0x060000) {
+                pls = [];
+                var plsLeft = polyline.getLeftOutline();
+                var plsRight = polyline.getRightOutline();
+                for (var i=0; i<plsLeft.length && i<plsRight.length; i++) {
+                    pls.push([plsLeft[i], plsRight[i]]);
+                }
+            }
+            else {
+                pls = polyline.getLeftRightOutline();
+            }
 
             var first = true;
             var lastSegment = undefined;
@@ -353,7 +364,7 @@ Explode.explodeEntity = function(entity, options) {
             var polySegments = polyline.getExploded();
             if (polySegments.length>0) {
                 for (k=0; k<polySegments.length; k++) {
-                    var shape = polySegments[k].data();
+                    var shape = getPtr(polySegments[k]);
 
                     // last shape might have zero length if polyline is closed geometrically and logically:
                     if (k===polySegments.length-1) {
@@ -399,7 +410,7 @@ Explode.explodeEntity = function(entity, options) {
             for (k=0; k<painterPaths.length; k++) {
                 shapes = painterPaths[k].getShapes();
                 for (n=0; n<shapes.length; n++) {
-                    shape = shapes[n].data();
+                    shape = getPtr(shapes[n]);
                     if (isSplineShape(shape)) {
                         shape = ShapeAlgorithms.splineToLineOrArc(shape, 0.01);
                     }
@@ -414,13 +425,13 @@ Explode.explodeEntity = function(entity, options) {
         shapes = entity.getShapes();
         for (k=0; k<shapes.length; k++) {
             if (shapes[k].isValid()) {
-                ret.push(shapes[k].data());
+                ret.push(getPtr(shapes[k]));
             }
         }
         var textData = entity.getData().getTextData();
         e = new RTextEntity(entity.getDocument(), textData);
         e.setSelected(true);
-        e.copyAttributesFrom(entity.data());
+        e.copyAttributesFrom(getPtr(entity));
         var textColor = document.getKnownVariable(RS.DIMCLRT, new RColor(RColor.ByBlock));
         e.setColor(textColor);
         ret.push(e);
@@ -430,7 +441,7 @@ Explode.explodeEntity = function(entity, options) {
     else if (isLeaderEntity(entity)) {
         shapes = entity.getShapes();
         for (k=0; k<shapes.length; k++) {
-            shape = shapes[k].data();
+            shape = getPtr(shapes[k]);
             ret.push(shape.clone());
         }
     }
@@ -448,7 +459,7 @@ Explode.explodeEntity = function(entity, options) {
             var d = textDatas[k];
             e = new RTextEntity(document, new RTextData(d))
             e.setSelected(true);
-            e.copyAttributesFrom(entity.data());
+            e.copyAttributesFrom(getPtr(entity));
             if (e.getColor()!==d.getColor()) {
                 e.setColor(d.getColor());
             }
@@ -460,7 +471,7 @@ Explode.explodeEntity = function(entity, options) {
     else if (isSolidEntity(entity)) {
         shapes = entity.getShapes();
         for (k=0; k<shapes.length; k++) {
-            shape = shapes[k].data();
+            shape = getPtr(shapes[k]);
             if (shape.countVertices()===4) {
                 var v3 = shape.getVertexAt(3);
                 shape.setVertexAt(3, shape.getVertexAt(2));
@@ -474,7 +485,7 @@ Explode.explodeEntity = function(entity, options) {
     else if (isFaceEntity(entity)) {
         shapes = entity.getShapes();
         for (k=0; k<shapes.length; k++) {
-            shape = shapes[k].data();
+            shape = getPtr(shapes[k]);
             ret.push(shape.clone());
         }
     }
@@ -490,7 +501,7 @@ Explode.explodeEntity = function(entity, options) {
                 var d = textDatas[k];
                 e = new RTextEntity(document, new RTextData(d))
                 e.setSelected(true);
-                e.copyAttributesFrom(entity.data());
+                e.copyAttributesFrom(getPtr(entity));
                 if (e.getColor()!==d.getColor()) {
                     e.setColor(d.getColor());
                 }
@@ -589,7 +600,7 @@ Explode.explodeEntity = function(entity, options) {
         e = new RTextEntity(document, d);
         e.setSelected(true);
         if (isFunction(entity.data)) {
-            e.copyAttributesFrom(entity.data());
+            e.copyAttributesFrom(getPtr(entity));
         }
         else {
             e.copyAttributesFrom(entity);
@@ -601,6 +612,7 @@ Explode.explodeEntity = function(entity, options) {
     else if (isBlockReferenceEntity(entity)) {
         var data = entity.getData();
         var pos = entity.getPosition();
+        var uniform = RMath.fuzzyCompare(entity.getScaleFactors().x, entity.getScaleFactors().y);
 
         // explode array into multiple block references:
         if (data.getColumnCount()>1 || data.getRowCount()>1) {
@@ -637,6 +649,12 @@ Explode.explodeEntity = function(entity, options) {
                     continue;
                 }
 
+                // ignore hatch in non-uniformly scaled block reference:
+                if (!uniform && isHatchEntity(subEntity)) {
+                    EAction.handleUserWarning(qsTr("Ignored hatch in block reference with non-uniform scale factors"));
+                    continue;
+                }
+
                 e = subEntity.clone();
                 //data.applyColumnRowOffsetTo(e, col, row);
                 // we need the old ID to update attribute parent IDs:
