@@ -17,8 +17,8 @@
  * along with QCAD.
  */
 
-include("library.js");
-include("map.js");
+include("scripts/library.js");
+include("scripts/map.js");
 
 function WidgetFactory() {
 }
@@ -76,10 +76,14 @@ WidgetFactory.createWidget = function(basePath, uiFile, parent) {
     if (!new QFileInfo(uiFile).isAbsolute()) {
         candidates = [
             uiFile,
-            basePath + "/" + uiFile,
-            ":" + uiFile,
-            ":" + basePath + "/" + uiFile
+            basePath + "/" + uiFile
         ];
+        if (!uiFile.startsWith(":")) {
+            candidates.push(":" + uiFile);
+        }
+        if (!basePath.startsWith(":")) {
+            candidates.push(":" + basePath + "/" + uiFile);
+        }
     }
     else {
         candidates = [
@@ -114,7 +118,7 @@ WidgetFactory.createWidget = function(basePath, uiFile, parent) {
 
     var formWidget = loader.load(buf, parent);
     buf.close();
-    loader.destroy();
+    destr(loader);
 
     if (isNull(formWidget)) {
         qDebug("WidgetFactory.createWidget: widget is NULL");
@@ -137,7 +141,7 @@ WidgetFactory.createDialog = function(basePath, uiFile, parent) {
     var dialog = WidgetFactory.createWidget(basePath, uiFile, parent);
 
     var flags = dialog.windowFlags();
-    flags = new Qt.WindowFlags(flags & ~(Qt.WindowContextHelpButtonHint));
+    flags = makeQtWindowFlags(flags & ~(Qt.WindowContextHelpButtonHint));
     dialog.setWindowFlags(flags);
 
     // a global function might be defined to do additional
@@ -167,15 +171,16 @@ WidgetFactory.getKey = function(group, obj) {
     var key = [g, obj.objectName];
 
     // correct key:
-    if (obj.toString() === "QRadioButton" || obj.toString() === "QToolButton") {
+    if (isOfType(obj, QRadioButton) || isOfType(obj, QToolButton)) {
         // correct to button group name:
-        if (isFunction(obj.group) && obj.group()) {
+
+        if (isFunction(obj.group) && !isNull(obj.group())) {
             key = [g, obj.group().objectName];
         }
         else {
             var parent = obj.parent();
             // correct to group box (parent) name:
-            if (parent && parent.toString()=="QGroupBox") {
+            if (parent && isOfType(parent, QGroupBox)) {
                 key = [g, parent.objectName];
             }
         }
@@ -249,8 +254,8 @@ WidgetFactory.saveState = function(widget, group, document, map) {
     for (var i = 0; i < children.length; ++i) {
         var c = children[i];
 
-        if (!c || isDeleted(c) || c.toString()==="QVariantAnimation" ||
-                c.toString()==="QWidgetAction" || c.objectName==="" ||
+        if (!c || isDeleted(c) || c.toString().startsWith("QVariantAnimation") ||
+                c.toString().startsWith("QWidgetAction") || c.objectName==="" ||
                 c.objectName==="Icon" || c.objectName==="qt_toolbar_ext_button") {
             continue;
         }
@@ -263,12 +268,12 @@ WidgetFactory.saveState = function(widget, group, document, map) {
 
         // ignore widgets that have been saved elsewhere (e.g. plugins might
         // save widgets contents by themselves in savePreferences):
-        if (typeof(c["Saved"]) != "undefined" && c["Saved"]===true) {
+        if (typeof(c.property("Saved")) != "undefined" && c.property("Saved")===true) {
             continue;
         }
 
         // skip children from other groups in this widget (for options toolbar):
-        if (typeof(c["SettingsGroup"]) != "undefined" && c["SettingsGroup"] != group) {
+        if (typeof(c.property("SettingsGroup")) != "undefined" && c.property("SettingsGroup") != group) {
             if (isNull(map)) {
                 continue;
             }
@@ -312,12 +317,12 @@ WidgetFactory.saveState = function(widget, group, document, map) {
         else if (isOfType(c, QComboBox) || isOfType(c, QFontComboBox)) {
             var forceSaveText = false;
             var forceSaveIndex = false;
-            if (typeof(c["ForceSaveText"]) != "undefined"
-                    && c["ForceSaveText"] === true) {
+            if (typeof(c.property("ForceSaveText")) != "undefined"
+                    && c.property("ForceSaveText") === true) {
                 forceSaveText = true;
             }
-            if (typeof(c["ForceSaveIndex"]) != "undefined"
-                    && c["ForceSaveIndex"] === true) {
+            if (typeof(c.property("ForceSaveIndex")) != "undefined"
+                    && c.property("ForceSaveIndex") === true) {
                 forceSaveIndex = true;
             }
             if (forceSaveIndex == true) {
@@ -373,7 +378,7 @@ WidgetFactory.saveState = function(widget, group, document, map) {
             }
         }
         else if (c.toString().startsWith("RFontChooserWidget")) {
-            value = c.getFont();
+            value = c.getChosenFont();
         }
 
         if (isNull(value)) {
@@ -382,23 +387,23 @@ WidgetFactory.saveState = function(widget, group, document, map) {
         }
 
         // save property
-        if (typeof(c["SaveProperty"]) != "undefined") {
-            var prop = c["SaveProperty"];
+        if (typeof(c.property("SaveProperty")) != "undefined") {
+            var prop = c.property("SaveProperty");
             RSettings.setValue(key + "." + prop, c[prop]);
         }
 
         // widgets with dynamic property "RequiresRestart" trigger a
         // restart application warning after changing preferences:
-        if (typeof(c["RequiresRestart"]) != "undefined"
-            && c["RequiresRestart"] === true) {
+        if (typeof(c.property("RequiresRestart")) != "undefined"
+            && c.property("RequiresRestart") === true) {
             WidgetFactory.requiresRestart = true;
         }
 
         // widgets can be ignored by setting the dynamic property
         // "SaveContents" = false
         var saveContents = true;
-        if (typeof(c["SaveContents"]) != "undefined"
-                && c["SaveContents"] === false) {
+        if (typeof(c.property("SaveContents")) != "undefined"
+                && c.property("SaveContents") === false) {
             saveContents = false;
         }
 
@@ -457,7 +462,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
     }
 
     // Qt5: QWebView has no scriptable children method:
-    if (!isFunction(widget["children"])) {
+    if (!isFunction(widget.children)) {
         return;
     }
 
@@ -466,7 +471,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
         var c = children[i];
         
         if (!c || isDeleted(c)) {
-            break;
+            continue;
         }
 
         // ignore widgets without name:
@@ -486,8 +491,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
 
         // skip children from other groups in this widget (for options toolbar):
         // but not if used from a test [map != undefined]
-        if (isNull(map) && typeof (c["SettingsGroup"]) != "undefined"
-                && c["SettingsGroup"] !== group) {
+        if (isNull(map) && typeof (c.property("SettingsGroup")) != "undefined" && c.property("SettingsGroup") !== group) {
             continue;
         }
 
@@ -498,7 +502,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
 
         // handle widgets which have their own reset method
         var hasOwnReset = false;
-        if (typeof(c["hasOwnReset"]) != "undefined" && c["hasOwnReset"] == true) {
+        if (typeof(c.property("hasOwnReset")) != "undefined" && c.property("hasOwnReset") == true) {
             hasOwnReset = true;
         }
         if (reset && hasOwnReset) {
@@ -509,10 +513,9 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
         }
         
         var key = WidgetFactory.getKeyString(group, c);
-        var value;
-        if (reset && !isNull(c.defaultValue) && (typeof(c["SettingsGroup"])=="undefined" ||
-                c["SettingsGroup"]===group)) {
-            value = c.defaultValue;
+        var value = undefined;
+        if (reset && !isNull(c.property("defaultValue")) && (typeof(c.property("SettingsGroup"))=="undefined" || c.property("SettingsGroup")===group)) {
+            value = c.property("defaultValue");
         } else {
             if (!isNull(map)) {
                 value = map.get(key);                
@@ -543,14 +546,13 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
         // don't restore widgets that have been restored elsewhere (e.g. script
         // add-ons might load widgets contents by themselves in initPreferences):
         // [but always restore widgets if used from a test (map != undefined)]
-        if (isNull(map) && !reset && typeof (c["Loaded"]) != "undefined"
-                && c["Loaded"] === true) {
+        if (isNull(map) && !reset && c.property("Loaded")===true) {
             value = undefined;
         }
 
         // restore property
-        if (typeof(c["SaveProperty"]) != "undefined") {
-            var prop = c["SaveProperty"];
+        if (typeof(c.property("SaveProperty")) != "undefined") {
+            var prop = c.property("SaveProperty");
             var val = RSettings.getValue(key + "." + prop);
             if (!isNull(val)) {
                 c[prop] = val;
@@ -564,21 +566,12 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
 //        qDebug("restoring: ", c.objectName);
 //        qDebug("  value: ", value);
 
-        if (isOfType(c, QLineEdit)) {
-            WidgetFactory.connect(c.textChanged, signalReceiver, c.objectName);
-            c.textChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
-                c.setProperty("defaultValue", c.text);
-            }
-            if (!isNull(value)) {
-                c.text = value;
-            }
-            continue;
-        }
         if (isOfType(c, QPlainTextEdit)) {
-            WidgetFactory.connect(c.textChanged, signalReceiver, c.objectName);
-            c.textChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
+            if (!reset) {
+                WidgetFactory.connect(c.textChanged, signalReceiver, c.objectName);
+                WidgetFactory.connect(c.textChanged, WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
                 c.setProperty("defaultValue", c.toPlainText());
             }
             if (!isNull(value)) {
@@ -587,17 +580,24 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if (isOfType(c, RMathLineEdit)) {
-            WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
-            c.valueChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
+            if (!reset) {
+                WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
+                WidgetFactory.connect(c.valueChanged, WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
                 //c.defaultValue = [c.text, c.getDefaultUnit()];
-                c.defaultValue = c.text;
+                c.setProperty("defaultValue", c.text);
                 c.slotTextChanged(c.text);
             }
             if (!isNull(value)) {
                 // deprecated: value and default unit:
                 if (isArray(value) && value.length===2) {
-                    c.text = value[0];
+                    if (isNull(value[0])) {
+                        c.text = "";
+                    }
+                    else {
+                        c.text = value[0].toString();
+                    }
                 }
                 else {
                     if (isString(value)) {
@@ -611,11 +611,13 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if (isOfType(c, RMathComboBox)) {
-            WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
-            c.valueChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
+            if (!reset) {
+                WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
+                WidgetFactory.connect(c.valueChanged, WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
                 //c.defaultValue = [c.text, c.getDefaultUnit()];
-                c.defaultValue = c.currentText;
+                c.setProperty("defaultValue", c.currentText);
                 c.slotTextChanged(c.currentText);
             }
             if (!isNull(value)) {
@@ -628,33 +630,55 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             }
             continue;
         }
+        if (isOfType(c, QLineEdit)) {
+            if (!reset) {
+                WidgetFactory.connect(c.textChanged, signalReceiver, c.objectName);
+                WidgetFactory.connect(c.textChanged, WidgetFactory.topLevelWidget, "Setting");
+            }
+
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.text);
+            }
+            if (!isNull(value)) {
+                c.text = value.toString();
+            }
+            continue;
+        }
         if (isOfType(c, QToolButton) || isOfType(c, QPushButton)) {
 
-            if (!c.group() && !c.autoExclusive) {
+            if (isNull(c.group()) && !c.autoExclusive) {
                 if (c.checkable) {
-                    WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
-                    c.toggled.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-                    if (isNull(c.defaultValue)) {
-                        c.defaultValue = c.checked;
+                    if (!reset) {
+                        WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
+                        WidgetFactory.connect(c.toggled, WidgetFactory.topLevelWidget, "Setting");
+                    }
+                    if (isNull(c.property("defaultValue"))) {
+                        c.setProperty("defaultValue", c.checked);
                     }
                     if (!isNull(value)) {
                         c.checked = (value === true || value === "true");
                     }
                 }
                 else {
-                    WidgetFactory.connect(c.clicked, signalReceiver, c.objectName, false);
+                    if (!reset) {
+                        WidgetFactory.connect(c.clicked, signalReceiver, c.objectName, false);
+                    }
                 }
             }
             else {
-                WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
+                if (!reset) {
+                    WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
+                }
             }
             continue;
         }
         if (isOfType(c, QCheckBox)) {
-            WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
-            c.stateChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
-                c.defaultValue = c.checked;
+            if (!reset) {
+                WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
+                WidgetFactory.connect(c.stateChanged, WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.checked);
                 if (!isNull(signalReceiver)) {
                     f = signalReceiver["slot"+c.objectName+"Changed"];
                     if (isFunction(f)) {
@@ -670,9 +694,9 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
         if (isOfType(c, QRadioButton)) {
             if (!c.group() && !c.autoExclusive) {
                 WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
-                c.toggled.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-                if (isNull(c.defaultValue)) {
-                    c.defaultValue = c.checked;
+                WidgetFactory.connect(c.toggled, WidgetFactory.topLevelWidget, "Setting");
+                if (isNull(c.property("defaultValue"))) {
+                    c.setProperty("defaultValue", c.checked);
                 }
                 if (!isNull(value)) {
                     c.checked = (value === true || value == "true");
@@ -680,7 +704,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             }
             else {
                 WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
-                c.toggled.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+                WidgetFactory.connect(c.toggled, WidgetFactory.topLevelWidget, "Setting");
                 if (value==="true") {
                     c.checked = value;
                 }
@@ -691,11 +715,14 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if (isOfType(c, QButtonGroup)) {
-            WidgetFactory.connect(c["buttonClicked(QAbstractButton*)"], signalReceiver, c.objectName);
-            if (isNull(c.defaultValue)) {
+            if (!reset) {
+                WidgetFactory.connect(c["buttonClicked(QAbstractButton*)"], signalReceiver, c.objectName);
+                WidgetFactory.connect(c["buttonClicked(QAbstractButton*)"], WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
                 var button = c.checkedButton();
-                if (button) {
-                    c.defaultValue = button.objectName;
+                if (!isNull(button) && !isNull(button.objectName)) {
+                    c.setProperty("defaultValue", button.objectName);
                     if (!isNull(signalReceiver)) {
                         f = signalReceiver["slot"+c.objectName+"Changed"];
                         if (isFunction(f)) {
@@ -721,10 +748,12 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             }
         }
         if (isOfType(c, QComboBox) && c.editable) {
-            WidgetFactory.connect(c.editTextChanged, signalReceiver, c.objectName);
-            c.editTextChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
-                c.defaultValue = c.currentText;
+            if (!reset) {
+                WidgetFactory.connect(c.editTextChanged, signalReceiver, c.objectName);
+                WidgetFactory.connect(c.editTextChanged, WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.currentText);
                 if (!isNull(signalReceiver)) {
                     f = signalReceiver["slot" + c.objectName + "Changed"];
                     if (isFunction(f)) {
@@ -743,17 +772,21 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if ((isOfType(c, QComboBox) && !c.editable) || isOfType(c, QFontComboBox)) {
-            WidgetFactory.connect(c['currentIndexChanged(int)'], signalReceiver, c.objectName);
-            c["currentIndexChanged(int)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+            if (!reset) {
+                WidgetFactory.connect(c['currentIndexChanged(int)'], signalReceiver, c.objectName);
+                WidgetFactory.connect(c['currentIndexChanged(int)'], WidgetFactory.topLevelWidget, "Setting");
+            }
             hasData = false;
-            if (c.itemData(c.currentIndex)!=undefined) {
+            if (c.itemData(c.currentIndex)!=undefined || (c.count>0 && c.itemData(0)!=undefined)) {
                 hasData = true;
             }
-            if (isNull(c.defaultValue)) {
+            if (isNull(c.property("defaultValue"))) {
                 if (hasData) {
-                    c.defaultValue = c.itemData(c.currentIndex);
+                    if (c.currentIndex>=0 && c.currentIndex<c.count) {
+                        c.setProperty("defaultValue", c.itemData(c.currentIndex));
+                    }
                 } else {
-                    c.defaultValue = c.currentText;
+                    c.setProperty("defaultValue", c.currentText);
                 }
                 if (signalReceiver!=undefined) {
                     f = signalReceiver["slot" + c.objectName + "Changed"];
@@ -764,22 +797,25 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             }
             var forceSaveText = false;
             var forceSaveIndex = false;
-            if (typeof(c["ForceSaveText"]) != "undefined"
-                    && c["ForceSaveText"] == true) {
+            if (typeof(c.property("ForceSaveText")) != "undefined"
+                    && c.property("ForceSaveText") == true) {
                 forceSaveText = true;
             }
-            if (typeof(c["ForceSaveIndex"]) != "undefined"
-                    && c["ForceSaveIndex"] == true) {
+            if (typeof(c.property("ForceSaveIndex")) != "undefined"
+                    && c.property("ForceSaveIndex") == true) {
                 forceSaveIndex = true;
             }
             if (!isNull(value)) {
+                index = -1;
                 if (forceSaveIndex == true) {
-                    index = value;
+                    index = parseInt(value);
                 }
                 else if (forceSaveText == false && hasData) {
                     index = c.findData(value);
                 } else {
-                    index = c.findText(value);
+                    if (isString(value)) {
+                        index = c.findText(value);
+                    }
                 }
                 if (index !== -1) {
                     c.currentIndex = index;
@@ -789,10 +825,12 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if (isOfType(c, RColorCombo)) {
-            WidgetFactory.connect(c.editTextChanged, signalReceiver, c.objectName);
-            c["currentIndexChanged(int)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
-                c.defaultValue = c.getColor();
+            if (!reset) {
+                WidgetFactory.connect(c.editTextChanged, signalReceiver, c.objectName);
+                WidgetFactory.connect(c["currentIndexChanged(int)"], WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.getColor());
             }
             if (!isNull(value)) {
                 // color name given:
@@ -813,10 +851,12 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if (isOfType(c, RLineweightCombo)) {
-            WidgetFactory.connect(c.editTextChanged, signalReceiver, c.objectName);
-            c["currentIndexChanged(int)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
-                c.defaultValue = c.getLineweight();
+            if (!reset) {
+                WidgetFactory.connect(c.editTextChanged, signalReceiver, c.objectName);
+                WidgetFactory.connect(c["currentIndexChanged(int)"], WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.getLineweight());
             }
             if (!isNull(value)) {
                 if (isString(value)) {
@@ -827,10 +867,12 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if (isOfType(c, RLinetypeCombo)) {
-            WidgetFactory.connect(c.editTextChanged, signalReceiver, c.objectName);
-            c["currentIndexChanged(int)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
-                c.defaultValue = c.getLinetypePattern();
+            if (!reset) {
+                WidgetFactory.connect(c.editTextChanged, signalReceiver, c.objectName);
+                WidgetFactory.connect(c["currentIndexChanged(int)"], WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.getLinetypePattern());
             }
             if (!isNull(value)) {
                 c.setLinetypePattern(value);
@@ -838,17 +880,18 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if (isOfType(c, QSpinBox) || isOfType(c, QDoubleSpinBox)) {
-            if (isOfType(c, QSpinBox)) {
-                WidgetFactory.connect(c["valueChanged(int)"], signalReceiver, c.objectName);
-                c["valueChanged(int)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+            if (!reset) {
+                if (isOfType(c, QSpinBox)) {
+                    WidgetFactory.connect(c["valueChanged(int)"], signalReceiver, c.objectName);
+                    WidgetFactory.connect(c["valueChanged(int)"], WidgetFactory.topLevelWidget, "Setting");
+                }
+                else {
+                    WidgetFactory.connect(c["valueChanged(double)"], signalReceiver, c.objectName);
+                    WidgetFactory.connect(c["valueChanged(double)"], WidgetFactory.topLevelWidget, "Setting");
+                }
             }
-            else {
-                WidgetFactory.connect(c["valueChanged(double)"], signalReceiver, c.objectName);
-                c["valueChanged(double)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            }
-
-            if (isNull(c.defaultValue)) {
-                c.defaultValue = c.value;
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.value);
                 if (signalReceiver!=undefined) {
                     f = signalReceiver["slot" + c.objectName + "Changed"];
                     if (isFunction(f)) {
@@ -857,16 +900,22 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
                 }
             }
             if (!isNull(value)) {
-                c.value = value;
+                if (isOfType(c, QSpinBox)) {
+                    c.value = parseInt(value);
+                }
+                else {
+                    c.value = parseFloat(value);
+                }
             }
             continue;
         }
         if (isOfType(c, QSlider)) {
-            WidgetFactory.connect(c["valueChanged(int)"], signalReceiver, c.objectName);
-            c["valueChanged(int)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-
-            if (isNull(c.defaultValue)) {
-                c.defaultValue = c.value;
+            if (!reset) {
+                WidgetFactory.connect(c["valueChanged(int)"], signalReceiver, c.objectName);
+                WidgetFactory.connect(c["valueChanged(int)"], WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.value);
                 if (signalReceiver!=undefined) {
                     f = signalReceiver["slot" + c.objectName + "Changed"];
                     if (isFunction(f)) {
@@ -884,25 +933,25 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             // if the list contents should not be saved to
             // the configuration file or document:
             var saveContents = true;
-            if (typeof(c["SaveContents"]) != "undefined"
-                    && c["SaveContents"] == false) {
+            if (typeof(c.property("SaveContents")) != "undefined"
+                    && c.property("SaveContents") == false) {
                 saveContents = false;
             }
 
             if (saveContents) {
-                if (isNull(c.defaultValue)) {
+                if (isNull(c.property("defaultValue"))) {
                     var items = [];
                     for (j = 0; j < c.count; ++j) {
                         items.push(c.item(j).text());
                     }
-                    c.defaultValue = items;
+                    c.setProperty("defaultValue", items);
                 }
                 if (!isNull(value)) {
                     c.addItems(value);
                 }
             } else {
-                if (isNull(c.defaultValue) && !isNull(c.currentItem())) {
-                    c.defaultValue = c.currentItem().data(Qt.UserRole);
+                if (isNull(c.property("defaultValue")) && !isNull(c.currentItem())) {
+                    c.setProperty("defaultValue", c.currentItem().data(Qt.UserRole));
                 }
                 if (!isNull(value)) {
                     for (j=0; j<c.count; ++j) {
@@ -947,17 +996,21 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
                 }
             }
 
-            WidgetFactory.connect(c.itemChanged, signalReceiver, c.objectName);
-            c.itemSelectionChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            c.model().rowsInserted.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");            
+            if (!reset) {
+                WidgetFactory.connect(c.itemChanged, signalReceiver, c.objectName);
+                c.itemSelectionChanged.connect(WidgetFactory.topLevelWidget, WidgetFactory.topLevelWidget.slotSettingChanged);
+                c.model().rowsInserted.connect(WidgetFactory.topLevelWidget, WidgetFactory.topLevelWidget.slotSettingChanged);
+            }
             
             continue;
         }
         if (isOfType(c, RFontChooserWidget)) {
-            WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
-            c.valueChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
-                c.defaultValue = c.getFont();
+            if (!reset) {
+                WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
+                c.valueChanged.connect(WidgetFactory.topLevelWidget, WidgetFactory.topLevelWidget.slotSettingChanged);
+            }
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.getChosenFont());
             }
             if (!isNull(value)) {
                 if (isString(value)) {
@@ -966,7 +1019,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
                     value = fnt;
                 }
 
-                c.setFont(value);
+                c.setChosenFont(value);
             }
             continue;
         }
@@ -1008,6 +1061,7 @@ WidgetFactory.connect = function(sig, signalReceiver, objectName, isValue) {
     }
 
     // connect signal to given function:
+    // obsolete?
     if (isFunction(signalReceiver)) {
         sig.connect(signalReceiver);
         return;
@@ -1024,7 +1078,12 @@ WidgetFactory.connect = function(sig, signalReceiver, objectName, isValue) {
 
     //if (eval("signalReceiver." + slot) != undefined) {
     if (!isNull(signalReceiver[slot])) {
-        sig.connect(signalReceiver, slot);
+        if (RSettings.getQtVersion() >= 0x060000) {
+            sig.connect(signalReceiver, signalReceiver[slot]);
+        }
+        else {
+            sig.connect(signalReceiver, slot);
+        }
     }
 };
 
@@ -1043,7 +1102,11 @@ WidgetFactory.moveChildren = function(sourceWidget, targetWidget, settingsGroup)
     // on this (especially on macOS):
     var children = sourceWidget.children();
     for(var i=0;i<children.length;++i) {
-        var w=children[i];
+        var w = children[i];
+        if (isNull(w)) {
+            continue;
+        }
+
         w.setProperty("SettingsGroup", settingsGroup);
 
         // add separator:
@@ -1099,7 +1162,7 @@ WidgetFactory.moveChildren = function(sourceWidget, targetWidget, settingsGroup)
 };
 
 WidgetFactory.adjustIcons = function(includeBasePath, widget) {
-    if (!isFunction(widget.children)) {
+    if (isNull(widget) || !isFunction(widget.children)) {
         return;
     }
 
@@ -1224,9 +1287,9 @@ WidgetFactory.initLineEdit = function(lineEdit, dimension) {
     });
 };
 
-WidgetFactory.initTextBrowser = function(textBrowser, linkHandler, slot) {
+WidgetFactory.initTextBrowser = function(textBrowser, slot) {
     textBrowser.openLinks = false;
-    textBrowser.anchorClicked.connect(linkHandler, slot);
+    textBrowser.anchorClicked.connect(slot);
 };
 
 //WidgetFactory.initWebView = function(webView, linkHandler, slot) {
@@ -1469,7 +1532,9 @@ WidgetFactory.installComboBoxEventFilter = function(widget) {
             isOfType(c, RLineweightCombo) ||
             isOfType(c, RLinetypeCombo)) {
 
-            c.installEventFilter(new REventFilter(QEvent.Wheel.valueOf(), true));
+            if (isFunction(c.installEventFilter)) {
+                c.installEventFilter(new REventFilter(QEvent.Wheel.valueOf(), true));
+            }
             c.focusPolicy = Qt.ClickFocus;
             continue;
         }
