@@ -288,7 +288,7 @@ function setUpDragAndDrop(appWin) {
         event.acceptProposedAction();
     });
 
-    appWin.drop.connect(function(evt) {
+    appWin.drop.connect(function(event) {
         // workaround for Qt keyboard focus bug:
         var appWin = RMainWindowQt.getMainWindow();
         if (!isNull(appWin)) {
@@ -297,13 +297,15 @@ function setUpDragAndDrop(appWin) {
             appWin.setFocus(Qt.OtherFocusReason);
         }
 
-        var urls = getUrlsFromMimeData(evt.mimeData());
+        var urls = getUrlsFromMimeData(event.mimeData());
         var urlStrings = [];
         for (var i = 0; i < urls.length; ++i) {
             urlStrings.push(urls[i].toString());
         }
 
         openFiles(urlStrings, false);
+
+        event.acceptProposedAction();
     });
 }
 
@@ -320,7 +322,7 @@ function loadTranslations(addOns, splash) {
 
     // load C++ translations:
     var modules = ["qt", "assistant", "qt_help", "qcadcore", "qcadentity", "qcadgui"];
-    if (RSettings.isQt(5)) {
+    if (RSettings.isQt(5) || RSettings.isQt(6)) {
         modules.unshift("qtbase");
     }
 
@@ -729,7 +731,14 @@ function main() {
     //RDebug.stopTimer(0, "initializing add-ons");
 
     // auto load scripts in AutoLoad folders for global script engine:
-    var files = RAutoLoadEcma.getAutoLoadFiles();
+
+    var files;
+    if (RSettings.isQt(6)) {
+        files = RAutoLoadJs.getAutoLoadFiles();
+    }
+    else {
+        files = RAutoLoadEcma.getAutoLoadFiles();
+    }
     for (i=0; i<files.length; i++) {
         include(files[i]);
     }
@@ -767,7 +776,7 @@ function main() {
 
     if (!isNull(splash)) {
         splash.close();
-        splash.destroy();
+        destr(splash);
     }
 
     postInitAddOns(addOns);
@@ -844,7 +853,7 @@ function main() {
     // don't use RSettings below this point
 
     // and we're done:
-    appWin.destroy();
+    destr(appWin);
     qDebug("done");
 }
 
