@@ -135,7 +135,9 @@ function destr(obj) {
         obj.destr();
     }
     else {
-        obj.destroy();
+        if (isFunction(obj.destroy)) {
+            obj.destroy();
+        }
     }
 }
 
@@ -571,7 +573,12 @@ function isEllipseEntity(obj) {
  * \return true if the given object is an ellipse arc entity (REllipseEntity).
  */
 function isEllipseArcEntity(obj) {
-    return (isOfType(obj, REllipseEntity) || isOfType(obj, REllipseEntityPointer)) && !obj.isFullEllipse();
+    if (RSettings.getQtVersion() < 0x060000) {
+        return (isOfType(obj, REllipseEntity) || isOfType(obj, REllipseEntityPointer)) && !obj.isFullEllipse();
+    }
+    else {
+        return isOfType(obj, REllipseEntity);
+    }
 }
 
 /**
@@ -2628,7 +2635,12 @@ function getMainWindow() {
 }
 
 function getCurrentDateTime(format) {
-    return new QDateTime(QDateTime.currentDateTime()).toString(format);
+    if (RSettings.getQtVersion() >= 0x060000) {
+        return QDateTime.currentDateTime().toString(format);
+    }
+    else {
+        return new QDateTime(QDateTime.currentDateTime()).toString(format);
+    }
 }
 
 function mergeProperties(obj1,obj2) {
@@ -3116,10 +3128,10 @@ function setUtf8Codec(ts) {
 
 function readTextFile(fileName) {
     var file = new QFile(fileName);
-    var flags = new QIODevice.OpenMode(QIODevice.ReadOnly | QIODevice.Text);
+    var flags = makeQIODeviceOpenMode(QIODevice.ReadOnly, QIODevice.Text);
     if (file.open(flags)) {
         var textStream = new QTextStream(file);
-        textStream.setCodec("UTF-8");
+        setUtf8Codec(textStream);
         var contents = textStream.readAll();
         file.close();
         return contents;
@@ -3130,10 +3142,10 @@ function readTextFile(fileName) {
 
 function writeTextFile(fileName, str) {
     var file = new QFile(fileName);
-    var flags = new QIODevice.OpenMode(QIODevice.WriteOnly | QIODevice.Text);
+    var flags = makeQIODeviceOpenMode(QIODevice.WriteOnly, QIODevice.Text);
     if (file.open(flags)) {
         var textStream = new QTextStream(file);
-        textStream.setCodec("UTF-8");
+        setUtf8Codec(textStream);
         textStream.writeString(str);
         file.close();
     }
@@ -3253,6 +3265,36 @@ function makeQtItemFlags() {
     return makeFlags.apply(this, argumentsNew);
 }
 
+function makeQtKeyboardModifiers() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(Qt.KeyboardModifiers);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeQtMouseButtons() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(Qt.MouseButtons);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeQEventLoopProcessEventsFlags() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(QEventLoop.ProcessEventsFlags);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeQItemSelectionModelSelectionFlags() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(QItemSelectionModel.SelectionFlags);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeQAbstractItemViewEditTriggers() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(QAbstractItemView.EditTriggers);
+    return makeFlags.apply(this, argumentsNew);
+}
+
 function makeFlags() {
     if (RSettings.isQt(6)) {
         var ret = 0;
@@ -3268,6 +3310,20 @@ function makeFlags() {
     }
 }
 
+function getRGraphicsView(view) {
+    if (RSettings.getQtVersion()>=0x060000) {
+        return view;
+    }
+    else {
+        if (isFunction(view.getRGraphicsView)) {
+            return view.getRGraphicsView();
+        }
+        else {
+            return view;
+        }
+    }
+}
+
 // fix QPlainTextEdit API for Qt 5:
 if (!isFunction(QPlainTextEdit.prototype.toPlainText)) {
     QPlainTextEdit.prototype.toPlainText = function() {
